<?php
session_start();
require 'conn.php'; // Ensure database connection

header("Content-Type: application/json");

if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    $userMessage = strtolower(trim($_POST['message'])); // Normalize message

    // Step 1: Greeting Check
    $greetings = ["hello", "hi", "hey", "good morning", "good afternoon", "good evening"];
    if (in_array($userMessage, $greetings)) {
        $_SESSION['step'] = 1;
        echo json_encode(["response" => "Hello! What's your full name? 😊"]);
        exit;
    }

    // Step 2: Collect Name
    if (isset($_SESSION['step']) && $_SESSION['step'] === 1) {
        if (strlen($userMessage) < 2) {
            echo json_encode(["response" => "That doesn't seem like a name. Please enter your full name."]);
            exit;
        }
        $_SESSION['user_name'] = ucfirst($userMessage); // Store name
        $_SESSION['step'] = 2;
        echo json_encode(["response" => "Nice to meet you, {$_SESSION['user_name']}! 🎉 Which province are you from?"]);
        exit;
    }

    // Step 3: Collect Province
    if (isset($_SESSION['step']) && $_SESSION['step'] === 2) {
        if (strlen($userMessage) < 3) {
            echo json_encode(["response" => "Please enter a valid province name."]);
            exit;
        }
        $_SESSION['user_province'] = ucfirst($userMessage); // Store province
        $_SESSION['step'] = 3;
        echo json_encode(["response" => "Thanks, {$_SESSION['user_name']} from {$_SESSION['user_province']}! 🌍 How can I assist you today?"]);
        exit;
    }

    // Step 4: Ensure User Has Entered Name & Province Before Asking Questions
    if (!isset($_SESSION['user_name']) || !isset($_SESSION['user_province'])) {
        echo json_encode(["response" => "You need to enter your name and province before asking a question. Please say 'Hello' to start!"]);
        exit;
    }

    // Step 5: Fetch response from database
    $stmt = $conn->prepare("SELECT response FROM chatbot_responses WHERE LOWER(question) LIKE LOWER(?) LIMIT 1");
    $searchPattern = "%$userMessage%";
    $stmt->execute([$searchPattern]);
    $result = $stmt->fetch(PDO::FETCH_ASSOC);

    if ($result) {
        echo json_encode(["response" => $result['response']]);
    } else {
        echo json_encode(["response" => "I don't have an answer for that yet. 🤔 You can check the FAQs or contact support."]);
    }
    exit;
}
?>
