<?php
include 'conn.php'; // Database connection

// Initialize error message
$error = "";

// Handle form submission to add new knowledge base entries
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    if (isset($_POST['question']) && isset($_POST['answer']) && isset($_POST['category'])) {
        $question = htmlspecialchars($_POST['question']);
        $answer = htmlspecialchars($_POST['answer']);
        $category_id = (int)$_POST['category'];

        if (!empty($question) && !empty($answer) && $category_id > 0) {
            $stmt = $conn->prepare("INSERT INTO knowledge_base (category_id, title, content) VALUES (?, ?, ?)");
            $stmt->execute([$category_id, $question, $answer]);

            echo "<script>alert('Knowledge added successfully!'); window.location.href='ai.php';</script>";
        } else {
            $error = "All fields are required!";
        }
    } else {
        $error = "Invalid form submission!";
    }
}
// Pagination settings
$items_per_page = 20; // Number of items per page
$page = isset($_GET['page']) && is_numeric($_GET['page']) ? (int)$_GET['page'] : 1; // Get current page number, default to 1
$start_from = ($page - 1) * $items_per_page; // Calculate the starting point for the query

// Fetch knowledge base entries with category names and apply pagination
$query = $conn->prepare("SELECT knowledge_base.*, categories.category_name 
                         FROM knowledge_base 
                         JOIN categories ON knowledge_base.category_id = categories.id 
                         ORDER BY knowledge_base.id DESC 
                         LIMIT ?, ?");

// Ensure integers are passed
$query->bindValue(1, (int) $start_from, PDO::PARAM_INT);
$query->bindValue(2, (int) $items_per_page, PDO::PARAM_INT);
$query->execute();
$faqs = $query->fetchAll(PDO::FETCH_ASSOC);

// Get the total number of entries for pagination calculation
$total_faqs_query = $conn->query("SELECT COUNT(*) FROM knowledge_base");
$total_faqs = $total_faqs_query->fetchColumn();
$total_pages = ceil($total_faqs / $items_per_page);


?>



<!DOCTYPE html>
<html lang="en">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>RCCG DTCE AI Knowledge Base</title>
    <link rel="stylesheet" href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css">
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.4.2/css/all.min.css">
    <!-- Favicon -->
    <link rel="icon" type="image/png" href="dist/img/icon2.png">
    <style>
        body {
            background-color: #f8f9fa;
            min-height: 100vh;
            display: flex;
            flex-direction: column;
        }

        .navbar {
            background-color: #007BFF;
        }

        .navbar-brand {
            color: #FFD700;
            font-weight: bold;
        }

        .nav-link {
            color: white;
        }

        .container {
            flex: 1;
        }

        .footer {
            background: #007BFF;
            color: white;
            text-align: center;
            padding: 10px;
            width: 100%;
        }

        /* CHATBOX CONTAINER */
        .chatbox {
            position: fixed;
            bottom: 80px;
            /* Adjusted to avoid overlapping with toggle */
            right: 20px;
            width: 400px;
            height: 500px;
            background: white;
            border-radius: 10px;
            box-shadow: 0px 4px 10px rgba(0, 0, 0, 0.2);
            display: none;
            /* Initially hidden */
            flex-direction: column;
            z-index: 1000;
            /* Ensures it appears above other elements */
        }

        /* CHATBOX HEADER */
        .chatbox-header {
            background: #007BFF;
            color: white;
            padding: 15px;
            font-weight: bold;
            text-align: center;
            border-top-left-radius: 10px;
            border-top-right-radius: 10px;
        }

        /* CHATBOX MESSAGES */
        .chatbox-messages {
            flex: 1;
            padding: 10px;
            overflow-y: auto;
            max-height: 400px;
            scrollbar-width: thin;
            scrollbar-color: #007BFF #f0f0f0;
        }

        /* Custom scrollbar styling */
        .chatbox-messages::-webkit-scrollbar {
            width: 6px;
        }

        .chatbox-messages::-webkit-scrollbar-thumb {
            background: #007BFF;
            border-radius: 10px;
        }

        .chatbox-messages::-webkit-scrollbar-track {
            background: #f0f0f0;
        }

        /* CHATBOX FOOTER */
        .chatbox-footer {
            display: flex;
            padding: 10px;
            border-top: 1px solid #ddd;
            background: #f9f9f9;
            border-bottom-left-radius: 10px;
            border-bottom-right-radius: 10px;
        }

        /* CHAT INPUT FIELD */
        .chatbox-footer input {
            flex: 1;
            padding: 10px;
            border: 1px solid #ddd;
            border-radius: 5px;
            outline: none;
            font-size: 14px;
        }

        /* SEND BUTTON */
        .chatbox-footer button {
            background: #007BFF;
            color: white;
            border: none;
            padding: 8px 12px;
            margin-left: 5px;
            border-radius: 5px;
            cursor: pointer;
            font-size: 16px;
        }

        .chatbox-footer button:hover {
            background: #0056b3;
        }

        /* CHATBOX TOGGLE BUTTON (fa-comment icon) */
        .chatbox-toggle {
            position: fixed;
            bottom: 20px;
            right: 20px;
            background: #007BFF;
            color: white;
            padding: 12px;
            border-radius: 50%;
            cursor: pointer;
            font-size: 20px;
            display: flex;
            align-items: center;
            justify-content: center;
            width: 50px;
            height: 50px;
            box-shadow: 0px 4px 8px rgba(0, 0, 0, 0.3);
            transition: background 0.3s ease;
            z-index: 1100;
            /* Ensures it's always above the chatbox */
        }

        .chatbox-toggle:hover {
            background: #0056b3;
        }

        /* WHEN CHATBOX IS OPEN, MOVE TOGGLE BUTTON UP */
        .chatbox.open~.chatbox-toggle {
            bottom: 520px;
            /* Moves it up to avoid overlap */
        }

        /* RESPONSIVE ADJUSTMENTS */
        @media screen and (max-width: 500px) {
            .chatbox {
                width: 90%;
                right: 5%;
            }
        }

        /* DARK MODE STYLES */
        .dark-mode .chatbox {
            background-color: #1e1e1e;
            color: white;
            border: 1px solid #444;
        }

        .dark-mode .chatbox-header {
            background-color: #222;
            color: #ffffff;
        }

        .dark-mode .chatbox-messages {
            background-color: #2c2c2c;
        }

        .dark-mode .chatbox-footer {
            background-color: #222;
            border-top: 1px solid #444;
        }

        .dark-mode .chatbox-footer input {
            background-color: #333;
            color: #ffffff;
            border: 1px solid #555;
        }

        .dark-mode .chatbox-footer button {
            background-color: #444;
        }

        .dark-mode .chatbox-toggle {
            background-color: #444;
        }



        /* DARK MODE MAIN STYLES */
        .dark-mode {
            background-color: #121212;
            color: #ffffff;
        }

        /* ✅ Navbar & Footer */
        .dark-mode .navbar,
        .dark-mode .footer {
            background-color: #000 !important;
            /* Black background */
            color: #ffffff !important;
            /* White text */
        }

        /* ✅ Navbar Links & Buttons */
        .dark-mode .navbar a.nav-link,
        .dark-mode .navbar .navbar-brand,
        .dark-mode .navbar-toggler,
        .dark-mode .navbar-toggler-icon {
            color: #ffffff !important;
        }

        /* ✅ Navbar Buttons */
        .dark-mode .navbar .btn,
        .dark-mode .navbar .nav-item .nav-link {
            background-color: #222 !important;
            color: #ffffff !important;
            border: 1px solid #444 !important;
        }

        .dark-mode .navbar .btn:hover,
        .dark-mode .navbar .nav-item .nav-link:hover {
            background-color: #444 !important;
        }

        /* ✅ Cards */
        .dark-mode .card {
            background-color: #1e1e1e !important;
            color: #ffffff !important;
            border: 1px solid #444 !important;
        }

        /* ✅ Text Elements */
        .dark-mode h1,
        .dark-mode h2,
        .dark-mode h3,
        .dark-mode h4,
        .dark-mode h5,
        .dark-mode h6,
        .dark-mode p,
        .dark-mode small,
        .dark-mode strong,
        .dark-mode .category,
        .dark-mode .text-muted {
            color: #ffffff !important;
        }

        /* ✅ Search Box */
        .dark-mode .form-control {
            background-color: #222 !important;
            color: #ffffff !important;
            border: 1px solid #555 !important;
        }

        /* ✅ Search Box Placeholder Text */
        .dark-mode .form-control::placeholder {
            color: #bbb !important;
        }

        /* ✅ Dark Mode Toggle Button */
        .dark-mode #darkModeToggle {
            background-color: #ffffff !important;
            color: #121212 !important;
            border: 1px solid #ffffff !important;
        }

        .dark-mode #darkModeToggle:hover {
            background-color: #dddddd !important;
            color: #000 !important;
        }

        /* ✅ Card Titles & Text */
        .dark-mode .card-title,
        .dark-mode .card-text {
            color: #ffffff !important;
        }

        /* ✅ FAQ Category */
        .dark-mode .faq-category {
            color: #ffffff !important;
        }

        /*  */
        .navbar-brand {
            display: flex;
            align-items: center;
            /* Aligns logo and text vertically */
        }

        .navbar-logo {
            max-width: 100px;
            /* Reduce the width */
            max-height: 100px;
            /* Reduce the height */
            width: auto;
            /* Let width adjust proportionally */
            height: auto;
            /* Let height adjust proportionally */
        }


        .navbar-brand span {
            font-size: 1.25rem;
            /* Adjust text size */
            font-weight: bold;
            /* Optional: for bolder text */
        }

        /* Light mode (default) styling for list group items */
        .list-group-item {
            background-color: #ffffff;
            /* white background */
            color: #333333;
            /* dark text */
        }

        /* Dark mode styling with .dark-mode class */
        .dark-mode .list-group-item {
            background-color: #000000;
            /* black background */
            color: #ffffff;
            /* white text */
        }

        /* Optional: Highlight the strong text in dark mode */
        .dark-mode .list-group-item strong {
            color: #ffd700;
            /* gold text for emphasis */
        }

        /* Optional: Hover effect for better UX in dark mode */
        .dark-mode .list-group-item:hover {
            background-color: #333333;
            /* slightly lighter black background on hover */
        }

        /* Logo styling */
        .chatbox-logo {
            width: 40px;
            /* Adjust logo size */
            height: 40px;
            /* Adjust logo size */
            margin-right: 10px;
            /* Space between the logo and the text */
        }


        .user-icon {
            width: 20px;
        }

        .rccg-logo {
            border-radius: 50%;
            width: 20px;

        }

        /* Chatbox input */
        #chat-input {
            width: 80%;
            padding: 10px;
            margin-right: 10px;
        }

        /* Chatbox button */
        button {
            padding: 10px;
            background-color: #4CAF50;
            color: white;
            border: none;
            cursor: pointer;
        }

        button:hover {
            background-color: #45a049;
        }

        .pagination {
            display: inline-flex;
            padding: 0;
            list-style: none;
            border-radius: 0.25rem;
        }

        .page-item {
            margin: 0 2px;
        }

        .page-link {
            color: #007bff;
            padding: 10px 15px;
            text-decoration: none;
            border: 1px solid #ddd;
        }

        .page-item.active .page-link {
            background-color: #007bff;
            color: white;
            border-color: #007bff;
        }
    </style>
</head>

<body>
    <nav class="navbar navbar-dark navbar-expand-lg bg-primary">
        <div class="container-fluid">
            <a class="navbar-brand d-flex align-items-center" href="#">
                <img src="dist/img/dtce.png" alt="Logo" class="navbar-logo">
                <span class="ms-2 text-white">RCCG DTCE KNOWLEDGE BASE</span>
            </a>
            <button class="navbar-toggler" type="button" data-bs-toggle="collapse" data-bs-target="#navbarNav">
                <span class="navbar-toggler-icon"></span>
            </button>
            <div class="collapse navbar-collapse" id="navbarNav">
                <ul class="navbar-nav ms-auto">
                    <li class="nav-item"><a class="nav-link" href="https://conventionportal.rccgjuniorchurch.org/convention/">Home</a></li>
                    <li class="nav-item"><a class="nav-link" href="#">FAQs</a></li>
                    <li class="nav-item"><a class="nav-link" href="#">Contact</a></li>
                    <li class="nav-item"><a class="nav-link" href="#" onclick="toggleChatbox()">AI Chat</a></li>
                </ul>
                <button id="darkModeToggle" class="btn btn-outline-light ms-3">🌙 Dark Mode</button>
            </div>
        </div>
    </nav>


    <div class="container py-4">
        <!-- Welcome Card for RCCG DTCE Coordinators -->
        <div id="welcome-card" class="card shadow-lg mb-4 mx-auto" style="max-width: 700px;">
            <div class="card-body">
                <h2 class="card-title text-primary fw-bold mb-3">
                    <i class="fas fa-users-cog"></i> Welcome RCCG DTCE Coordinators!
                </h2>
                <p class="card-text fs-4 mb-4">
                    We are excited to welcome you to the first-of-its-kind RCCG DTCE Knowledge Base System!
                    This platform has been designed specifically to streamline and simplify the access to valuable information for all coordinators.
                </p>
                <p class="card-text fs-5 mb-4">
                    Here are some key features of the system:
                </p>
                <ul class="list-group mb-4">
                    <li class="list-group-item"><strong>Easy Access:</strong> Search and access answers to frequently asked questions (FAQs) with ease.</li>
                    <li class="list-group-item"><strong>Knowledge Sharing:</strong> Share your experiences and learn from the collective wisdom of other coordinators.</li>
                    <li class="list-group-item"><strong>Real-time Updates:</strong> Get the latest updates on various programs, policies, and procedures directly from RCCG DTCE.</li>
                    <li class="list-group-item"><strong>Interactive Discussions:</strong> Engage with other coordinators and share ideas to improve the system and its usage.</li>
                    <li class="list-group-item"><strong>24/7 Availability:</strong> Access the knowledge base anytime, anywhere, with just a few clicks.</li>
                </ul>


                <p class="card-text fs-5 mb-4">
                    The RCCG DTCE Knowledge Base System is here to support you in your role and make your tasks more efficient. We hope you find this system helpful and easy to use.
                    Please feel free to reach out for any support or questions.
                </p>
                <button id="explore-button" class="btn btn-primary btn-lg" onclick="exploreSystem()">Explore the Knowledge Base</button>
            </div>
        </div>

        <!-- Search & Pagination Container (Hidden Initially) -->
        <div id="search-pagination-container" style="display: none;">
            <!-- Search Box -->
            <div id="search-section" class="text-center mb-4">
                <div class="input-group mb-4 mx-auto" style="max-width: 700px;">
                    <span class="input-group-text"><i class="fas fa-search"></i></span>
                    <input type="text" class="form-control search-box" id="search" placeholder="Search for answers...">
                </div>
            </div>

            <!-- No Results Message (Hidden by Default) -->
            <div id="no-results" class="text-center text-danger fw-bold mb-4" style="display: none;">
                <div class="card text-center shadow-sm mx-auto" style="max-width: 700px;">
                    <div class="card-body">
                        <i class="fas fa-exclamation-triangle"></i>
                        <h5 class="card-title">No results found</h5>
                        <p class="card-text">Sorry, we couldn't find any answers. Try different keywords.</p>
                    </div>
                </div>
            </div>

            <?php
            $cards_per_page = 20;
            $page = isset($_GET['page']) ? (int)$_GET['page'] : 1;
            $start = ($page - 1) * $cards_per_page;
            $end = $start + $cards_per_page - 1;
            $count = 0;
            ?>

            <!-- Search Section -->


            <!-- No Results Message (Hidden by Default) -->
            <div id="no-results" class="text-center text-danger fw-bold mb-4" style="display: none;">
                <div class="card text-center shadow-sm mx-auto" style="max-width: 700px;">
                    <div class="card-body">
                        <i class="fas fa-exclamation-triangle"></i>
                        <h5 class="card-title">No results found</h5>
                        <p class="card-text">Sorry, we couldn't find any answers. Try different keywords.</p>
                    </div>
                </div>
            </div>

            <!-- FAQ Section -->
            <div id="faq-section" class="container-fluid">
    <div class="row">
        <?php 
        $count = 0;
        foreach ($faqs as $faq): ?>
            <div class="col-md-3 mb-4 faq-item">
                <div class="card h-100 shadow-sm">
                    <div class="card-body">
                        <h5 class="card-title text-primary fw-bold">
                            <i class="fas fa-question-circle"></i>
                            <?= htmlspecialchars($faq['title']) ?>
                        </h5>
                        <p class="card-text">
                            <i class="fas fa-info-circle text-secondary"></i>
                            <?= nl2br(htmlspecialchars($faq['content'])) ?>
                        </p>
                        <small class="text-muted">
                            <i class="fas fa-tag"></i> Category:
                            <strong><?= htmlspecialchars($faq['category_name']) ?></strong>
                        </small>
                    </div>
                </div>
            </div>

            <?php 
            $count++;
            // Ensure a new row starts after every 4 items
            if ($count % 4 == 0 && $count < count($faqs)) {
                echo '</div><div class="row">';
            }
            ?>
        <?php endforeach;
        
       
        
        
        ?>
    </div>
</div>




            <!-- Pagination -->
            <div id="pagination-container" class="pagination-container text-center mt-4">
    <ul class="pagination">
        <?php if ($page > 1): ?>
            <li class="page-item"><a class="page-link" href="?page=1">First</a></li>
            <li class="page-item"><a class="page-link" href="?page=<?php echo $page - 1; ?>">Prev</a></li>
        <?php endif; ?>

        <?php for ($i = 1; $i <= $total_pages; $i++): ?>
            <li class="page-item <?php if ($i == $page) echo 'active'; ?>">
                <a class="page-link" href="?page=<?php echo $i; ?>"><?php echo $i; ?></a>
            </li>
        <?php endfor; ?>

        <?php if ($page < $total_pages): ?>
            <li class="page-item"><a class="page-link" href="?page=<?php echo $page + 1; ?>">Next</a></li>
            <li class="page-item"><a class="page-link" href="?page=<?php echo $total_pages; ?>">Last</a></li>
        <?php endif; ?>
    </ul>
</div>
        </div>


        <!-- Search Script -->
        <script src="https://code.jquery.com/jquery-3.6.0.min.js"></script>
        <script>
            $(document).ready(function() {
                $("#search").on("input", function() {
                    let searchText = $(this).val().toLowerCase().trim();
                    let hasResults = false;

                    $(".faq-item").each(function() {
                        let title = $(this).find(".card-title").text().toLowerCase();
                        let content = $(this).find(".card-text").text().toLowerCase();

                        if (title.includes(searchText) || content.includes(searchText)) {
                            $(this).show();
                            hasResults = true;
                        } else {
                            $(this).hide();
                        }
                    });

                    if (searchText === "") {
                        $(".faq-item").show();
                        $("#no-results").hide();
                    } else {
                        $("#no-results").toggle(!hasResults);
                    }
                });
            });
        </script>


    </div>

    <script>
        // This function will be called when the Explore button is clicked
        // Show Search and FAQ Section only after clicking Explore
        function exploreSystem() {
            console.log("Explore button clicked");

            // Hide welcome message and explore button
            document.getElementById('welcome-card').style.display = 'none';
            document.getElementById('explore-button').style.display = 'none';

            // Show search, FAQ section, and pagination
            document.getElementById('search-pagination-container').style.display = 'block';
            document.getElementById('faq-section').style.display = 'block';
        }

        // Initially hide FAQ and pagination elements on the welcome page
        window.onload = function() {
            document.getElementById('faq-section').style.display = 'none'; // Hide FAQ section initially
            document.getElementById('search-pagination-container').style.display = 'none'; // Hide search & pagination initially
        };
        // Check if no FAQs are available in PHP
        <?php if (count($faqs) === 0): ?>
            document.getElementById('faq-section').style.display = 'none'; // Hide FAQ section if no results
            document.getElementById('no-results').style.display = 'block'; // Show no results message if no FAQs
        <?php else: ?>
            document.getElementById('no-results').style.display = 'none'; // Hide no results message if FAQs are available
            document.getElementById('faq-section').style.display = 'block'; // Show FAQ section if FAQs are available
        <?php endif; ?>

        // Handling search input
        document.getElementById('search').addEventListener('input', function() {
            let searchQuery = this.value.toLowerCase();
            let faqItems = document.querySelectorAll('.faq-item');
            let noResultsMessage = document.getElementById('no-results');
            let faqSection = document.getElementById('faq-section');

            let foundResults = false;

            // Loop through each FAQ item to check if it matches the search query
            faqItems.forEach(function(item) {
                let title = item.querySelector('.card-title').textContent.toLowerCase();
                let content = item.querySelector('.card-text').textContent.toLowerCase();

                if (title.includes(searchQuery) || content.includes(searchQuery)) {
                    item.style.display = 'block'; // Show matching item
                    foundResults = true;
                } else {
                    item.style.display = 'none'; // Hide non-matching item
                }
            });

            // Show No Results message if no matching FAQ items are found
            if (!foundResults) {
                noResultsMessage.style.display = 'block'; // Show "No results found"
            } else {
                noResultsMessage.style.display = 'none'; // Hide "No results found"
            }
        });
    </script>

    <!-- Chatbox -->
    <div class="chatbox" id="chatbox">
        <div class="chatbox-header">
            <img src="dist/img/icon.png" alt="RCCG DTCE Logo" class="chatbox-logo">
            RCCG DTCE ONLINE ASSISTANT
        </div>

        <div class="chatbox-messages" id="chat-messages"></div>
        <div class="chatbox-footer">
            <input type="text" id="chat-input" placeholder="Ask me anything...">
            <button onclick="sendMessage()"><i class="fas fa-paper-plane"></i></button>
        </div>
    </div>
    <div class="chatbox-toggle" onclick="toggleChatbox()"><i class="fas fa-comment"></i></div>

    <div class="footer">&copy; 2024 RCCG DTCE | Knowledge Base</div>




    <script>
        function toggleChatbox() {
            let chatbox = document.getElementById("chatbox");
            chatbox.style.display = chatbox.style.display === "none" || chatbox.style.display === "" ? "flex" : "none";
        }

        function sendMessage() {
            let input = document.getElementById("chat-input");
            let message = input.value.trim();

            if (message.length === 0) return; // Prevent empty messages

            let chatMessages = document.getElementById("chat-messages");

            // Add user message with icon (Prevent HTML Injection)
            let userDiv = document.createElement("div");
            userDiv.classList.add("message");
            userDiv.innerHTML = `<i class="fas fa-user user-icon"></i> <strong>You:</strong> `;
            let userText = document.createElement("span");
            userText.textContent = message; // Prevents script injection
            userDiv.appendChild(userText);
            chatMessages.appendChild(userDiv);

            // Prepare data for backend
            let formData = new FormData();
            formData.append("message", message);

            // Send message to chatbot.php
            fetch("chatbot.php", {
                    method: "POST",
                    body: formData
                })
                .then(response => response.json())
                .then(data => {
                    // Add chatbot response with logo
                    let botDiv = document.createElement("div");
                    botDiv.classList.add("message");
                    botDiv.innerHTML = `<img src="dist/img/icon2.png" alt="RCCG DTCE Logo" class="rccg-logo"> <strong>RCCG DTCE:</strong> `;
                    let botText = document.createElement("span");
                    botText.textContent = data.response; // Prevents script injection
                    botDiv.appendChild(botText);
                    chatMessages.appendChild(botDiv);

                    // Scroll to latest message
                    chatMessages.scrollTop = chatMessages.scrollHeight;
                })
                .catch(() => {
                    let errorDiv = document.createElement("div");
                    errorDiv.classList.add("message");
                    errorDiv.innerHTML = `<img src="dist/img/icon2.png" alt="RCCG DTCE Logo" class="rccg-logo"> <strong>RCCG DTCE:</strong> Sorry, I couldn't fetch a response.`;
                    chatMessages.appendChild(errorDiv);
                });

            input.value = "";
        }
    </script>
    <script src="https://code.jquery.com/jquery-3.6.0.min.js"></script>
    <script>
        $(document).ready(function() {
            // ✅ Load dark mode preference
            if (localStorage.getItem("darkMode") === "enabled") {
                $("body").addClass("dark-mode");
                $("#darkModeToggle").text("☀️ Light Mode");
            }

            // ✅ Toggle Dark Mode
            $("#darkModeToggle").click(function() {
                $("body").toggleClass("dark-mode");

                if ($("body").hasClass("dark-mode")) {
                    localStorage.setItem("darkMode", "enabled");
                    $(this).text("☀️ Light Mode");
                } else {
                    localStorage.setItem("darkMode", "disabled");
                    $(this).text("🌙 Dark Mode");
                }
            });

            //✅ Search Function
            $("#search").on("keyup", function() {
                var value = $(this).val().toLowerCase();
                var found = false;

                $(".faq-item").each(function() {
                    if ($(this).text().toLowerCase().includes(value)) {
                        $(this).show();
                        found = true;
                    } else {
                        $(this).hide();
                    }
                });

                $("#no-results").toggle(!found);
            });
        });

        function toggleChatbox() {
            let chatbox = document.getElementById("chatbox");
            let chatToggle = document.querySelector(".chatbox-toggle");

            chatbox.classList.toggle("open");

            if (chatbox.classList.contains("open")) {
                chatbox.style.display = "flex";
                chatToggle.style.bottom = "520px"; // Push button up when chatbox opens
            } else {
                chatbox.style.display = "none";
                chatToggle.style.bottom = "20px"; // Reset position when closed
            }
        }
    </script>

    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script>
</body>

</html>